@@ -28,6 +28,8 @@ from .utils import create_instance
 from .utils import positive_int_value
 from pyeclib_c import get_liberasurecode_version
 
+import warnings
+
 import logging
 from logging.handlers import SysLogHandler
 logger = logging.getLogger('pyeclib')
@@ -68,8 +70,8 @@ def PyECLibVersion(z, y, x):
 
 
 PYECLIB_MAJOR = 1
-PYECLIB_MINOR = 1
-PYECLIB_REV = 2
+PYECLIB_MINOR = 6
+PYECLIB_REV = 1
 PYECLIB_VERSION = PyECLibVersion(PYECLIB_MAJOR, PYECLIB_MINOR,
                                  PYECLIB_REV)
 
@@ -198,8 +200,15 @@ class ECDriver(object):
                     value = "flat_xor_hd"
                 elif value == "libphazr":
                     self.hd = 1
+
                 if PyECLib_EC_Types.has_enum(value):
                     self.ec_type = PyECLib_EC_Types.get_by_name(value)
+                    if self.ec_type in (PyECLib_EC_Types.jerasure_rs_vand,
+                                        PyECLib_EC_Types.jerasure_rs_cauchy):
+                        warnings.warn('Jerasure support is deprecated and '
+                                      'may be removed in a future release',
+                                      FutureWarning, stacklevel=2)
+
                 else:
                     raise ECBackendNotSupported(
                         "%s is not a valid EC type for PyECLib!" % value)
@@ -302,7 +311,6 @@ class ECDriver(object):
         :param missing_fragment_indexes: a list of integers representing
                                          the indexes of the fragments to be
                                          reconstructed.
-        :param destination_index: the index of the element to reconstruct
         :returns: a list of buffers (ordered by fragment index) containing
                   the reconstructed payload associated with the indexes
                   provided in missing_fragment_indexes
@@ -313,7 +321,7 @@ class ECDriver(object):
             available_fragment_payloads, missing_fragment_indexes)
 
     def fragments_needed(self, reconstruction_indexes,
-                         exclude_indexes=[]):
+                         exclude_indexes=None):
         """
         Determine which fragments are needed to reconstruct some subset of
         missing fragments.
@@ -330,6 +338,8 @@ class ECDriver(object):
         :raises: ECDriverError if there is an error during decoding or there
                  are not sufficient fragments to decode
         """
+        if exclude_indexes is None:
+            exclude_indexes = []
         return self.ec_lib_reference.fragments_needed(reconstruction_indexes,
                                                       exclude_indexes)
 
