@@ -26,6 +26,8 @@
 
 #include <stdio.h>
 #include <paths.h>
+#define PY_SSIZE_T_CLEAN
+#define Py_LIMITED_API 0x03050000
 #include <Python.h>
 #include <math.h>
 #include <bytesobject.h>
@@ -487,12 +489,12 @@ static PyObject *
 pyeclib_c_encode(PyObject *self, PyObject *args)
 {
   PyObject *pyeclib_obj_handle = NULL;
-  pyeclib_t *pyeclib_handle= NULL; 
+  pyeclib_t *pyeclib_handle = NULL;
   char **encoded_data = NULL;     /* array of k data buffers */
   char **encoded_parity = NULL;     /* array of m parity buffers */
   PyObject *list_of_strips = NULL;  /* list of encoded strips to return */
   char *data;                       /* param, data buffer to encode */
-  int data_len;                     /* param, length of data buffer */
+  Py_ssize_t data_len;              /* param, length of data buffer */
   uint64_t fragment_len;            /* length, in bytes of the fragments */
   int i;                            /* a counter */
   int ret = 0;
@@ -511,25 +513,25 @@ pyeclib_c_encode(PyObject *self, PyObject *args)
   ret = liberasurecode_encode(pyeclib_handle->ec_desc, data, data_len, &encoded_data, &encoded_parity, &fragment_len);
   if (ret < 0) {
     pyeclib_c_seterr(ret, "pyeclib_c_encode");
-    return NULL; 
+    return NULL;
   }
   
   /* Create the python list of fragments to return */
   list_of_strips = PyList_New(pyeclib_handle->ec_args.k + pyeclib_handle->ec_args.m);
   if (NULL == list_of_strips) {
     pyeclib_c_seterr(-ENOMEM, "pyeclib_c_encode");
-    return NULL; 
+    return NULL;
   }
   
   /* Add data fragments to the python list to return */
   for (i = 0; i < pyeclib_handle->ec_args.k; i++) {
-    PyList_SET_ITEM(list_of_strips, i, 
+    PyList_SetItem(list_of_strips, i,
                     PY_BUILDVALUE_OBJ_LEN(encoded_data[i], fragment_len));
   }
   
   /* Add parity fragments to the python list to return */
   for (i = 0; i < pyeclib_handle->ec_args.m; i++) {
-    PyList_SET_ITEM(list_of_strips, pyeclib_handle->ec_args.k + i, 
+    PyList_SetItem(list_of_strips, pyeclib_handle->ec_args.k + i,
                     PY_BUILDVALUE_OBJ_LEN(encoded_parity[i], fragment_len));
   }
 
@@ -885,7 +887,7 @@ pyeclib_c_decode(PyObject *self, PyObject *args)
         pyeclib_c_seterr(-EINVALIDPARAMS, "pyeclib_c_decode invalid range");
         goto error;
       }
-      PyList_SET_ITEM(ret_payload, i,
+      PyList_SetItem(ret_payload, i,
         PY_BUILDVALUE_OBJ_LEN(c_orig_payload + c_ranges[i].offset, c_ranges[i].length));
     }
   }
@@ -988,15 +990,15 @@ hex_encode_string(char *buf, uint32_t buf_len)
 {
   char *hex_encoded_buf = (char*)alloc_zeroed_buffer((buf_len * 2) + 1);
   char *hex_encoded_ptr = hex_encoded_buf;
-  int i;
+  uint32_t i;
 
   for (i = 0; i < buf_len; i++) {
-    hex_encoded_ptr += sprintf(hex_encoded_ptr, "%.2x", (unsigned char)buf[i]); 
+    hex_encoded_ptr += sprintf(hex_encoded_ptr, "%.2x", (unsigned char)buf[i]);
   }
 
   hex_encoded_buf[buf_len * 2] = 0;
- 
-  return hex_encoded_buf; 
+
+  return hex_encoded_buf;
 }
 
 static PyObject*
@@ -1040,7 +1042,7 @@ pyeclib_c_get_metadata(PyObject *self, PyObject *args)
   char *fragment = NULL;                            /* param, fragment from caller */
   fragment_metadata_t c_fragment_metadata;          /* structure to hold metadata */
   PyObject *fragment_metadata = NULL;               /* metadata object to return */
-  int fragment_len;                                 /* fragment length */
+  Py_ssize_t fragment_len;                          /* fragment length */
   int formatted;                                    /* format the metadata in a dict */
   int ret;
 
